==> openGion_dev_5.9.14.0.zip: opengion/uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GE34S.sql <==
/****************************************************************************/
/* GE34 ( 宛先ﾃｰﾌﾞﾙ )                                                       */
/*                                                                          */
/* Created : 2016/11/04 10:32:18                                            */
/****************************************************************************/
CREATE TABLE GE34 (
   YKNO     INTEGER                         DEFAULT 0   NOT NULL            /*  10 要求NO   */
 , GROUP_ID varchar           (  20 )                                       /*  20 ｸﾞﾙｰﾌﾟID */
 , DST_ID   varchar           (  10 )                   NOT NULL            /*  30 社員番号 */
 , DST_NAME varchar           ( 100 )                                       /*  40 名前     */
 , DST_ADDR varchar           ( 100 )                                       /*  50 ﾒｰﾙｱﾄﾞﾚｽ */
 , DST_KBN  varchar           (   1 )                   NOT NULL            /*  60 送信区分 */
 , UNIQ     int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ      varchar           (   1 )       DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET    varchar           (  14 )                                       /* 820 登録日時 */
 , PGSET    varchar           (  10 )                                       /* 830 作成PG   */
 , PGPSET   varchar           (  10 )                                       /* 840 作成親PG */
 , USRSET   varchar           (  10 )                                       /* 850 作成社員 */
 , DYUPD    varchar           (  14 )                                       /* 860 更新日時 */
 , PGUPD    varchar           (  10 )                                       /* 870 更新PG   */
 , PGPUPD   varchar           (  10 )                                       /* 880 更新親PG */
 , USRUPD   varchar           (  10 )                                       /* 890 更新者   */
);

==> openGion_dev_5.9.19.0.zip: opengion/uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GE34S.sql <==
/****************************************************************************/
/* GE34 ( 宛先ﾃｰﾌﾞﾙ )                                                       */
/*                                                                          */
/* Created : 2017/04/07 09:50:28                                            */
/****************************************************************************/
CREATE TABLE GE34 (
   YKNO     INTEGER                         DEFAULT 0   NOT NULL            /*  10 要求NO   */
 , GROUP_ID varchar           (  20 )                                       /*  20 ｸﾞﾙｰﾌﾟID */
 , DST_ID   varchar           (  10 )                   NOT NULL            /*  30 社員番号 */
 , DST_NAME varchar           ( 100 )                                       /*  40 名前     */
 , DST_ADDR varchar           ( 100 )                                       /*  50 ﾒｰﾙｱﾄﾞﾚｽ */
 , DST_KBN  varchar           (   1 )                   NOT NULL            /*  60 送信区分 */
 , UNIQ     int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ      varchar           (   1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET    varchar           (  14 )                                       /* 820 登録日時 */
 , PGSET    varchar           (  10 )                                       /* 830 作成PG   */
 , PGPSET   varchar           (  10 )                                       /* 840 作成親PG */
 , USRSET   varchar           (  10 )                                       /* 850 作成社員 */
 , DYUPD    varchar           (  14 )                                       /* 860 更新日時 */
 , PGUPD    varchar           (  10 )                                       /* 870 更新PG   */
 , PGPUPD   varchar           (  10 )                                       /* 880 更新親PG */
 , USRUPD   varchar           (  10 )                                       /* 890 更新者   */
);
